@@ -13,9 +13,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * License along with this library. If not, see <http://www.gnu.org/licenses/>.
  */
 
 /*
@@ -276,6 +274,10 @@
 #define GDK_dead_invertedbreve 0xfe6d
 #define GDK_dead_belowcomma 0xfe6e
 #define GDK_dead_currency 0xfe6f
+#define GDK_dead_lowline 0xfe90
+#define GDK_dead_aboveverticalline 0xfe91
+#define GDK_dead_belowverticalline 0xfe92
+#define GDK_dead_longsolidusoverlay 0xfe93
 #define GDK_dead_a 0xfe80
 #define GDK_dead_A 0xfe81
 #define GDK_dead_e 0xfe82
@@ -288,6 +290,7 @@
 #define GDK_dead_U 0xfe89
 #define GDK_dead_small_schwa 0xfe8a
 #define GDK_dead_capital_schwa 0xfe8b
+#define GDK_dead_greek 0xfe8c
 #define GDK_First_Virtual_Screen 0xfed0
 #define GDK_Prev_Virtual_Screen 0xfed1
 #define GDK_Next_Virtual_Screen 0xfed2
@@ -334,6 +337,12 @@
 #define GDK_Pointer_Accelerate 0xfefa
 #define GDK_Pointer_DfltBtnNext 0xfefb
 #define GDK_Pointer_DfltBtnPrev 0xfefc
+#define GDK_ch 0xfea0
+#define GDK_Ch 0xfea1
+#define GDK_CH 0xfea2
+#define GDK_c_h 0xfea3
+#define GDK_C_h 0xfea4
+#define GDK_C_H 0xfea5
 #define GDK_3270_Duplicate 0xfd01
 #define GDK_3270_FieldMark 0xfd02
 #define GDK_3270_Right2 0xfd03
@@ -613,9 +622,9 @@
 #define GDK_nacute 0x1f1
 #define GDK_ncaron 0x1f2
 #define GDK_odoubleacute 0x1f5
-#define GDK_udoubleacute 0x1fb
 #define GDK_rcaron 0x1f8
 #define GDK_uring 0x1f9
+#define GDK_udoubleacute 0x1fb
 #define GDK_tcedilla 0x1fe
 #define GDK_abovedot 0x1ff
 #define GDK_Hstroke 0x2a1
@@ -676,32 +685,32 @@
 #define GDK_uogonek 0x3f9
 #define GDK_utilde 0x3fd
 #define GDK_umacron 0x3fe
+#define GDK_Wcircumflex 0x1000174
+#define GDK_wcircumflex 0x1000175
+#define GDK_Ycircumflex 0x1000176
+#define GDK_ycircumflex 0x1000177
 #define GDK_Babovedot 0x1001e02
 #define GDK_babovedot 0x1001e03
 #define GDK_Dabovedot 0x1001e0a
-#define GDK_Wgrave 0x1001e80
-#define GDK_Wacute 0x1001e82
 #define GDK_dabovedot 0x1001e0b
-#define GDK_Ygrave 0x1001ef2
 #define GDK_Fabovedot 0x1001e1e
 #define GDK_fabovedot 0x1001e1f
 #define GDK_Mabovedot 0x1001e40
 #define GDK_mabovedot 0x1001e41
 #define GDK_Pabovedot 0x1001e56
-#define GDK_wgrave 0x1001e81
 #define GDK_pabovedot 0x1001e57
-#define GDK_wacute 0x1001e83
 #define GDK_Sabovedot 0x1001e60
-#define GDK_ygrave 0x1001ef3
+#define GDK_sabovedot 0x1001e61
+#define GDK_Tabovedot 0x1001e6a
+#define GDK_tabovedot 0x1001e6b
+#define GDK_Wgrave 0x1001e80
+#define GDK_wgrave 0x1001e81
+#define GDK_Wacute 0x1001e82
+#define GDK_wacute 0x1001e83
 #define GDK_Wdiaeresis 0x1001e84
 #define GDK_wdiaeresis 0x1001e85
-#define GDK_sabovedot 0x1001e61
-#define GDK_Wcircumflex 0x1000174
-#define GDK_Tabovedot 0x1001e6a
-#define GDK_Ycircumflex 0x1000176
-#define GDK_wcircumflex 0x1000175
-#define GDK_tabovedot 0x1001e6b
-#define GDK_ycircumflex 0x1000177
+#define GDK_Ygrave 0x1001ef2
+#define GDK_ygrave 0x1001ef3
 #define GDK_OE 0x13bc
 #define GDK_oe 0x13bd
 #define GDK_Ydiaeresis 0x13be
@@ -1196,6 +1205,7 @@
 #define GDK_leftdoublequotemark 0xad2
 #define GDK_rightdoublequotemark 0xad3
 #define GDK_prescription 0xad4
+#define GDK_permille 0xad5
 #define GDK_minutes 0xad6
 #define GDK_seconds 0xad7
 #define GDK_latincross 0xad9
@@ -1629,6 +1639,8 @@
 #define GDK_obarred 0x1000275
 #define GDK_SCHWA 0x100018f
 #define GDK_schwa 0x1000259
+#define GDK_EZH 0x10001b7
+#define GDK_ezh 0x1000292
 #define GDK_Lbelowdot 0x1001e36
 #define GDK_lbelowdot 0x1001e37
 #define GDK_Abelowdot 0x1001ea0
@@ -2034,6 +2046,86 @@
 #define GDK_braille_dots_1345678 0x10028fd
 #define GDK_braille_dots_2345678 0x10028fe
 #define GDK_braille_dots_12345678 0x10028ff
+#define GDK_Sinh_ng 0x1000d82
+#define GDK_Sinh_h2 0x1000d83
+#define GDK_Sinh_a 0x1000d85
+#define GDK_Sinh_aa 0x1000d86
+#define GDK_Sinh_ae 0x1000d87
+#define GDK_Sinh_aee 0x1000d88
+#define GDK_Sinh_i 0x1000d89
+#define GDK_Sinh_ii 0x1000d8a
+#define GDK_Sinh_u 0x1000d8b
+#define GDK_Sinh_uu 0x1000d8c
+#define GDK_Sinh_ri 0x1000d8d
+#define GDK_Sinh_rii 0x1000d8e
+#define GDK_Sinh_lu 0x1000d8f
+#define GDK_Sinh_luu 0x1000d90
+#define GDK_Sinh_e 0x1000d91
+#define GDK_Sinh_ee 0x1000d92
+#define GDK_Sinh_ai 0x1000d93
+#define GDK_Sinh_o 0x1000d94
+#define GDK_Sinh_oo 0x1000d95
+#define GDK_Sinh_au 0x1000d96
+#define GDK_Sinh_ka 0x1000d9a
+#define GDK_Sinh_kha 0x1000d9b
+#define GDK_Sinh_ga 0x1000d9c
+#define GDK_Sinh_gha 0x1000d9d
+#define GDK_Sinh_ng2 0x1000d9e
+#define GDK_Sinh_nga 0x1000d9f
+#define GDK_Sinh_ca 0x1000da0
+#define GDK_Sinh_cha 0x1000da1
+#define GDK_Sinh_ja 0x1000da2
+#define GDK_Sinh_jha 0x1000da3
+#define GDK_Sinh_nya 0x1000da4
+#define GDK_Sinh_jnya 0x1000da5
+#define GDK_Sinh_nja 0x1000da6
+#define GDK_Sinh_tta 0x1000da7
+#define GDK_Sinh_ttha 0x1000da8
+#define GDK_Sinh_dda 0x1000da9
+#define GDK_Sinh_ddha 0x1000daa
+#define GDK_Sinh_nna 0x1000dab
+#define GDK_Sinh_ndda 0x1000dac
+#define GDK_Sinh_tha 0x1000dad
+#define GDK_Sinh_thha 0x1000dae
+#define GDK_Sinh_dha 0x1000daf
+#define GDK_Sinh_dhha 0x1000db0
+#define GDK_Sinh_na 0x1000db1
+#define GDK_Sinh_ndha 0x1000db3
+#define GDK_Sinh_pa 0x1000db4
+#define GDK_Sinh_pha 0x1000db5
+#define GDK_Sinh_ba 0x1000db6
+#define GDK_Sinh_bha 0x1000db7
+#define GDK_Sinh_ma 0x1000db8
+#define GDK_Sinh_mba 0x1000db9
+#define GDK_Sinh_ya 0x1000dba
+#define GDK_Sinh_ra 0x1000dbb
+#define GDK_Sinh_la 0x1000dbd
+#define GDK_Sinh_va 0x1000dc0
+#define GDK_Sinh_sha 0x1000dc1
+#define GDK_Sinh_ssha 0x1000dc2
+#define GDK_Sinh_sa 0x1000dc3
+#define GDK_Sinh_ha 0x1000dc4
+#define GDK_Sinh_lla 0x1000dc5
+#define GDK_Sinh_fa 0x1000dc6
+#define GDK_Sinh_al 0x1000dca
+#define GDK_Sinh_aa2 0x1000dcf
+#define GDK_Sinh_ae2 0x1000dd0
+#define GDK_Sinh_aee2 0x1000dd1
+#define GDK_Sinh_i2 0x1000dd2
+#define GDK_Sinh_ii2 0x1000dd3
+#define GDK_Sinh_u2 0x1000dd4
+#define GDK_Sinh_uu2 0x1000dd6
+#define GDK_Sinh_ru2 0x1000dd8
+#define GDK_Sinh_e2 0x1000dd9
+#define GDK_Sinh_ee2 0x1000dda
+#define GDK_Sinh_ai2 0x1000ddb
+#define GDK_Sinh_o2 0x1000ddc
+#define GDK_Sinh_oo2 0x1000ddd
+#define GDK_Sinh_au2 0x1000dde
+#define GDK_Sinh_lu2 0x1000ddf
+#define GDK_Sinh_ruu2 0x1000df2
+#define GDK_Sinh_luu2 0x1000df3
+#define GDK_Sinh_kunddaliya 0x1000df4
 #define GDK_ModeLock 0x1008ff01
 #define GDK_MonBrightnessUp 0x1008ff02
 #define GDK_MonBrightnessDown 0x1008ff03
@@ -2188,6 +2280,13 @@
 #define GDK_Suspend 0x1008ffa7
 #define GDK_Hibernate 0x1008ffa8
 #define GDK_TouchpadToggle 0x1008ffa9
+#define GDK_TouchpadOn 0x1008ffb0
+#define GDK_TouchpadOff 0x1008ffb1
+#define GDK_AudioMicMute 0x1008ffb2
+#define GDK_Keyboard 0x1008ffb3
+#define GDK_WWAN 0x1008ffb4
+#define GDK_RFKill 0x1008ffb5
+#define GDK_AudioPreset 0x1008ffb6
 #define GDK_Switch_VT_1 0x1008fe01
 #define GDK_Switch_VT_2 0x1008fe02
 #define GDK_Switch_VT_3 0x1008fe03
@@ -2204,5 +2303,7 @@
 #define GDK_ClearGrab 0x1008fe21
 #define GDK_Next_VMode 0x1008fe22
 #define GDK_Prev_VMode 0x1008fe23
+#define GDK_LogWindowTree 0x1008fe24
+#define GDK_LogGrabInfo 0x1008fe25
 
 #endif /* __GDK_KEYSYMS_COMPAT_H__ */
