@@ -158,17 +158,18 @@ struct _GtkEntryClass
                                gint           *y,
 			       gint           *width,
 			       gint           *height);
+  void (* insert_emoji)       (GtkEntry             *entry);
 
   /*< private >*/
 
+  void (* toggle_direction)   (GtkEntry             *entry);
+
   /* Padding for future expansion */
   void (*_gtk_reserved1)      (void);
   void (*_gtk_reserved2)      (void);
   void (*_gtk_reserved3)      (void);
   void (*_gtk_reserved4)      (void);
   void (*_gtk_reserved5)      (void);
-  void (*_gtk_reserved6)      (void);
-  void (*_gtk_reserved7)      (void);
 };
 
 GDK_AVAILABLE_IN_ALL
