@@ -87,12 +87,12 @@ struct _GtkEntryCompletionClass
   gboolean (* cursor_on_match)  (GtkEntryCompletion *completion,
                                  GtkTreeModel       *model,
                                  GtkTreeIter        *iter);
+  void     (* no_matches)       (GtkEntryCompletion *completion);
 
   /* Padding for future expansion */
   void (*_gtk_reserved0) (void);
   void (*_gtk_reserved1) (void);
   void (*_gtk_reserved2) (void);
-  void (*_gtk_reserved3) (void);
 };
 
 /* core */
